@@ -9,6 +9,7 @@ import torch
 from torch import nn, einsum
 from torch.autograd import grad as torch_grad
 import torch.nn.functional as F
+from torch.linalg import vector_norm
 
 import torchaudio.transforms as T
 
@@ -33,11 +34,6 @@ def default(val, d):
 def cast_tuple(t, l = 1):
     return ((t,) * l) if not isinstance(t, tuple) else t
 
-# tensor helpers
-
-def l2norm(t, dim = -1):
-    return F.normalize(t, dim = dim)
-
 # gan losses
 
 def log(t, eps = 1e-20):
@@ -65,7 +61,7 @@ def gradient_penalty(wave, output, weight = 10):
     )[0]
 
     gradients = rearrange(gradients, 'b ... -> b (...)')
-    return weight * ((gradients.norm(2, dim = 1) - 1) ** 2).mean()
+    return weight * ((vector_norm(gradients, dim = 1) - 1) ** 2).mean()
 
 # discriminators
 
@@ -171,7 +167,8 @@ class ComplexSTFTDiscriminator(nn.Module):
         input_channels = 1,
         n_fft = 1024,
         hop_length = 256,
-        win_length = 1024
+        win_length = 1024,
+        normalized = False
     ):
         super().__init__()
         self.init_conv = ComplexConv2d(input_channels, channels, 7, padding = 3)
@@ -191,6 +188,8 @@ class ComplexSTFTDiscriminator(nn.Module):
 
         # stft settings
 
+        self.normalized = normalized
+
         self.n_fft = n_fft
         self.hop_length = hop_length
         self.win_length = win_length
@@ -211,6 +210,7 @@ class ComplexSTFTDiscriminator(nn.Module):
             self.n_fft,
             hop_length = self.hop_length,
             win_length = self.win_length,
+            normalized = self.normalized,
             return_complex = True
         )
 
@@ -352,11 +352,13 @@ class SoundStream(nn.Module):
         rq_ema_decay = 0.95,
         input_channels = 1,
         discr_multi_scales = (1, 0.5, 0.25),
+        stft_normalized = False,
         enc_cycle_dilations = (1, 3, 9),
         dec_cycle_dilations = (1, 3, 9),
         multi_spectral_window_powers_of_two = tuple(range(6, 12)),
         multi_spectral_n_ffts = 512,
         multi_spectral_n_mels = 64,
+        multi_spectral_normalized = False,
         recon_loss_weight = 1.,
         multi_spectral_recon_loss_weight = 1.,
         adversarial_loss_weight = 1.,
@@ -444,7 +446,9 @@ class SoundStream(nn.Module):
         self.discr_multi_scales = discr_multi_scales
         self.discriminators = nn.ModuleList([MultiScaleDiscriminator() for _ in range(len(discr_multi_scales))])
 
-        self.stft_discriminator = ComplexSTFTDiscriminator()
+        self.stft_discriminator = ComplexSTFTDiscriminator(
+            normalized = stft_normalized
+        )
 
         # multi spectral reconstruction
 
@@ -469,6 +473,7 @@ class SoundStream(nn.Module):
                 win_length = win_length,
                 hop_length = win_length // 4,
                 n_mels = n_mels,
+                normalized = multi_spectral_normalized
             )
 
             self.mel_spec_transforms.append(melspec_transform)
@@ -617,7 +622,7 @@ class SoundStream(nn.Module):
                 log_orig_mel, log_recon_mel = map(log, (orig_mel, recon_mel))
 
                 l1_mel_loss = (orig_mel - recon_mel).abs().sum(dim = -2).mean()
-                l2_log_mel_loss = alpha * l2norm(log_orig_mel - log_recon_mel, dim = -2).mean()
+                l2_log_mel_loss = alpha * vector_norm(log_orig_mel - log_recon_mel, dim = -2).mean()
 
                 multi_spectral_recon_loss = multi_spectral_recon_loss + l1_mel_loss + l2_log_mel_loss
 
